@@ -5,7 +5,7 @@ use v5.10.0;  # recursive regex subgroups
 
 use Exporter 5.57 qw(import);
 
-our $VERSION = '0.000002';
+our $VERSION = '0.000003';
 
 our @EXPORT_OK = qw(
     $URL_SEARCH_RE
@@ -16,6 +16,10 @@ our @EXPORT_OK = qw(
 our $URL_SEARCH_RE = do {
     my $general_unicode = qr{
         [^\p{ASCII}\p{Control}\p{Space}\p{Punct}]
+    |
+        [\x{2010}\x{2011}\x{2012}\x{2013}\x{2014}\x{2015}]
+        # HYPHEN, NON-BREAKING HYPHEN,
+        # FIGURE DASH, EN DASH, EM DASH, HORIZONTAL BAR
     }xms;
 
     my $protocol = qr{
